package
Version:
v0.0.0-...-683bc26
Opens a new window with list of versions in this module.
Published: Sep 3, 2024
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type ModuleScreen interface {
Drawmodul(width, outputAreaHeight, inputAreaWidth, inputAreaY int, outputText []string, inputBuffer strings.Builder)
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.